window.Gleam.initSearch([{"doc":"stacky","title":"stacky","content":"# Stacky ☆ BEAM stack trace in Gleam\n\n## a stack trace of stack frames with module name, function name, arity, file name and line number\n\n[![Package\n&lt;a href=&quot;https://github.com/inoas/stacky/releases&quot;&gt;&lt;img src=&quot;https://img.shields.io/github/release/inoas/stacky&quot; alt=&quot;GitHub release&quot;&gt;&lt;/a&gt;\n&lt;a href=&quot;https://discord.gg/Fm8Pwmy&quot;&gt;&lt;img src=&quot;https://img.shields.io/discord/768594524158427167?color=blue&quot; alt=&quot;Discord chat&quot;&gt;&lt;/a&gt;\n![CI](https://github.com/inoas/stacky/workflows/test/badge.svg?branch=main)\nVersion](https://img.shields.io/hexpm/v/stacky)](https://hex.pm/packages/stacky)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/stacky/)\n![Erlang-compatible](https://img.shields.io/badge/target-erlang-b83998)\n\nBest used with [pprint](https://hexdocs.pm/pprint/).\n\n```shell\ngleam add stacky\ngleam add pprint\n```\n\n## Usage\n\n```gleam\nimport pprint\nimport stacky\n\npub fn main() {\n  let stack =\n    stacky.trace()\n    // See the strack trace:\n    |&gt; pprint.debug\n\n  let frame =\n    stack\n    |&gt; stacky.frame(0)\n    // See the top most stack frame, from this call site:\n    |&gt; pprint.debug\n\n  frame\n  |&gt; stacky.gleam_module_name\n  // See the current module name, from this call site:\n  |&gt; pprint.debug\n\n  frame\n  |&gt; stacky.function_name\n  // See the current function name, from this call site:\n  |&gt; pprint.debug\n\n  // prints gleam module.function and erlang with line number to stdout\n  frame |&gt; stacky.print_frame_ln\n}\n```\n\n`stdout`:\n\n```gleam\nStackTrace([\n  StackFrame(\n    ErlangModuleName(&quot;stacky&quot;),\n    FunctionName(&quot;main&quot;),\n    FunctionArity(0),\n    ErlangFileName(&quot;stacky/build/dev/erlang/stacky/_gleam_artefacts/stacky.erl&quot;),\n    ErlangLineNumber(202),\n  ),\n  StackFrame(\n    ErlangModuleName(&quot;stacky@@main&quot;),\n    FunctionName(&quot;run&quot;),\n    FunctionArity(1),\n    ErlangFileName(&quot;stacky/build/dev/erlang/stacky/_gleam_artefacts/stacky@@main.erl&quot;),\n    ErlangLineNumber(11),\n  ),\n  StackFrame(\n    ErlangModuleName(&quot;erl_eval&quot;),\n    FunctionName(&quot;do_apply&quot;),\n    FunctionArity(7),\n    ErlangFileName(&quot;erl_eval.erl&quot;),\n    ErlangLineNumber(746),\n  ),\n  StackFrame(\n    ErlangModuleName(&quot;init&quot;),\n    FunctionName(&quot;start_it&quot;),\n    FunctionArity(1),\n    ErlangFileName([\n      110, 111, 45, 102, 105, 108, 101,\n    ]),\n    ErlangLineNumber(-1),\n  ),\n  StackFrame(\n    ErlangModuleName(&quot;init&quot;),\n    FunctionName(&quot;start_em&quot;),\n    FunctionArity(1),\n    ErlangFileName([\n      110, 111, 45, 102, 105, 108, 101,\n    ]),\n    ErlangLineNumber(-1),\n  ),\n  StackFrame(\n    ErlangModuleName(&quot;init&quot;),\n    FunctionName(&quot;do_boot&quot;),\n    FunctionArity(3),\n    ErlangFileName([\n      110, 111, 45, 102, 105, 108, 101,\n    ]),\n    ErlangLineNumber(-1),\n  ),\n])\nStackFrame(\n  ErlangModuleName(&quot;stacky&quot;),\n  FunctionName(&quot;main&quot;),\n  FunctionArity(0),\n  ErlangFileName(&quot;stacky/build/dev/erlang/stacky/_gleam_artefacts/stacky.erl&quot;),\n  ErlangLineNumber(202),\n)\n```\n\n```\n&quot;stacky&quot;\n```\n\n```\n&quot;main&quot;\n```\n\n```\nstacky.main - arity: 0 - erlang file: stacky/build/dev/erlang/stacky/_gleam_artefacts/stacky.erl:202\n```\n\n## Demo\n\n```shell\ngleam run -m stacky/internal/sub_dir/example_in_sub_dir.gleam\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/stacky&gt;.\n","url":"index.html"},{"doc":"stacky","title":"ErlangFileName","content":"pub type ErlangFileName {\n  ErlangFileName(String)\n}\n\nErlangFileName(String)\n\n\nSynonyms:\nstacky.ErlangFileName\nstacky ErlangFileName","url":"stacky.html#ErlangFileName"},{"doc":"stacky","title":"ErlangLineNumber","content":"pub type ErlangLineNumber {\n  ErlangLineNumber(Int)\n}\n\nErlangLineNumber(Int)\n\n\nSynonyms:\nstacky.ErlangLineNumber\nstacky ErlangLineNumber","url":"stacky.html#ErlangLineNumber"},{"doc":"stacky","title":"ErlangModuleName","content":"pub type ErlangModuleName {\n  ErlangModuleName(String)\n}\n\nErlangModuleName(String)\n\n\nSynonyms:\nstacky.ErlangModuleName\nstacky ErlangModuleName","url":"stacky.html#ErlangModuleName"},{"doc":"stacky","title":"FunctionArity","content":"pub type FunctionArity {\n  FunctionArity(Int)\n}\n\nFunctionArity(Int)\n\n\nSynonyms:\nstacky.FunctionArity\nstacky FunctionArity","url":"stacky.html#FunctionArity"},{"doc":"stacky","title":"FunctionName","content":"pub type FunctionName {\n  FunctionName(String)\n}\n\nFunctionName(String)\n\n\nSynonyms:\nstacky.FunctionName\nstacky FunctionName","url":"stacky.html#FunctionName"},{"doc":"stacky","title":"StackFrame","content":"pub type StackFrame {\n  StackFrame(\n    erlang_module_name: ErlangModuleName,\n    function_name: FunctionName,\n    function_arity: FunctionArity,\n    erlang_file_name: ErlangFileName,\n    erlang_line_number: ErlangLineNumber,\n  )\n}\n\nStackFrame(\n  erlang_module_name: ErlangModuleName,\n  function_name: FunctionName,\n  function_arity: FunctionArity,\n  erlang_file_name: ErlangFileName,\n  erlang_line_number: ErlangLineNumber,\n)\n\n\nSynonyms:\nstacky.StackFrame\nstacky StackFrame","url":"stacky.html#StackFrame"},{"doc":"stacky","title":"StackFrameTuple","content":"pub type StackFrameTuple =\n  #(String, String, Int, String, Int)\n\n\nSynonyms:\nstacky.StackFrameTuple\nstacky StackFrameTuple","url":"stacky.html#StackFrameTuple"},{"doc":"stacky","title":"StackTrace","content":"pub type StackTrace {\n  StackTrace(List(StackFrame))\n}\n\nStackTrace(List(StackFrame))\n\n\nSynonyms:\nstacky.StackTrace\nstacky StackTrace","url":"stacky.html#StackTrace"},{"doc":"stacky","title":"erlang_file_name","content":"pub fn erlang_file_name(stack_frame: StackFrame) -&gt; String\n\nSynonyms:\nstacky.erlang_file_name\nstacky erlang_file_name","url":"stacky.html#erlang_file_name"},{"doc":"stacky","title":"erlang_line_number","content":"pub fn erlang_line_number(stack_frame: StackFrame) -&gt; Int\n\nSynonyms:\nstacky.erlang_line_number\nstacky erlang_line_number","url":"stacky.html#erlang_line_number"},{"doc":"stacky","title":"erlang_module_name","content":"pub fn erlang_module_name(stack_frame: StackFrame) -&gt; String\n\nSynonyms:\nstacky.erlang_module_name\nstacky erlang_module_name","url":"stacky.html#erlang_module_name"},{"doc":"stacky","title":"frame","content":"pub fn frame(stacktrace: StackTrace, index: Int) -&gt; StackFrame\n\nSynonyms:\nstacky.frame\nstacky frame","url":"stacky.html#frame"},{"doc":"stacky","title":"frame_to_string","content":"pub fn frame_to_string(stack_frame: StackFrame) -&gt; String\n\nSynonyms:\nstacky.frame_to_string\nstacky frame_to_string","url":"stacky.html#frame_to_string"},{"doc":"stacky","title":"function_arity","content":"pub fn function_arity(stack_frame: StackFrame) -&gt; Int\n\nSynonyms:\nstacky.function_arity\nstacky function_arity","url":"stacky.html#function_arity"},{"doc":"stacky","title":"function_name","content":"pub fn function_name(stack_frame: StackFrame) -&gt; String\n\nSynonyms:\nstacky.function_name\nstacky function_name","url":"stacky.html#function_name"},{"doc":"stacky","title":"gleam_module_name","content":"pub fn gleam_module_name(stack_frame: StackFrame) -&gt; String\n\nSynonyms:\nstacky.gleam_module_name\nstacky gleam_module_name","url":"stacky.html#gleam_module_name"},{"doc":"stacky","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\nstacky.main\nstacky main","url":"stacky.html#main"},{"doc":"stacky","title":"print_frame_ln","content":"pub fn print_frame_ln(stack_frame: StackFrame) -&gt; Nil\n\nSynonyms:\nstacky.print_frame_ln\nstacky print_frame_ln","url":"stacky.html#print_frame_ln"},{"doc":"stacky","title":"trace","content":"pub fn trace() -&gt; StackTrace\n\nSynonyms:\nstacky.trace\nstacky trace","url":"stacky.html#trace"},{"doc":"stacky","title":"stacky","content":"","url":"stacky.html"}]);